import aiohttp

class translate:

    def __init__(self, client_id, client_secret):
        self.client_id = client_id
        self.client_secret = client_secret
    
    async def translate(self, source, target, text) -> dict:
        async with aiohttp.ClientSession() as session:
            request_url = "https://openapi.naver.com/v1/papago/n2mt"
            headers= {"X-Naver-Client-Id": self.client_id, "X-Naver-Client-Secret": self.client_secret}
            params = {"source": source, "target": target, "text": text}
            async with session.post(request_url, headers=headers, data=params) as resp:
                result = await resp.json()
                return result['message']['result']['translatedText']




from setuptools import setup, find_packages


with open('README.md', encoding='utf-8') as f:
    long_description = f.read()

setup(name='translatetool',
version='1.0.2',
description='A Papago Translate module.',
author='Jaewoo Lee',
author_email='jaewoolee82@kakao.com',
url='https://github.com/jaewoolee82/translatetool',
license='MIT',
py_modules=['translatetool'],
python_requires='>=3',
install_requires=['aiohttp'],
packages=['translatetool'],
long_description=long_description,
long_description_content_type='text/markdown'
)